@@ -4,7 +4,7 @@ vfplot_poplr <- function( sl, pval, vfinfo, newWindow = FALSE, txtfont = "mono",
                           outerSymbol = "circles", innerSymbol = "circles",
                           outerSize = 1, innerSize = 1,
                           outerInch = 0.24, innerInch = 0.12,
-                          lengthLines = 3.0, thicknessLines = 2,
+                          lengthLines = 0, thicknessLines = 0,
                           colorMapType = "pval", colorScale = NULL,
                           ringMapType  = NULL, ringScale  = NULL,
                           imparedVision = 10, borderThickness = 2,
